@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: proc.ml,v 1.13 2007/02/09 13:31:14 doligez Exp $ *)
+(* $Id: proc.ml,v 1.14 2007/10/30 12:37:16 xleroy Exp $ *)
 
 (* Description of the Intel 386 processor *)
 
@@ -181,7 +181,8 @@ let contains_calls = ref false
 (* Calling the assembler *)
 
 let assemble_file infile outfile =
-  Ccomp.command ("as -o " ^ Filename.quote outfile ^ " " ^ Filename.quote infile)
+  Ccomp.command (Config.asm ^ " -o " ^
+                 Filename.quote outfile ^ " " ^ Filename.quote infile)
 
 open Clflags;;
 open Config;;
